@@ -4,7 +4,7 @@
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
+    the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -226,8 +226,8 @@ bool CD::prev_track()
 
 bool CD::seek_forward( const int seconds )
   {
-  if( status != playing || !timelist.size() ||
-      ( !linear_ && !playlist_.size() ) ) return false;
+  if( status != playing || timelist.empty() ||
+      ( !linear_ && playlist_.empty() ) ) return false;
 
   Msf_time target = time_abs + Msf_time( 0, seconds );
   Msf_time end = timelist.back().end;
@@ -252,8 +252,8 @@ bool CD::seek_forward( const int seconds )
 
 bool CD::seek_backward( const int seconds )
   {
-  if( status != playing || !timelist.size() ||
-      ( !linear_ && !playlist_.size() ) ) return false;
+  if( status != playing || timelist.empty() ||
+      ( !linear_ && playlist_.empty() ) ) return false;
 
   Msf_time target = time_abs - Msf_time( 0, seconds );
   Msf_time start = timelist.front().start;
@@ -301,7 +301,7 @@ const char * CD::loop_name() const
 void CD::playlist( const std::vector< int > & pl )
   {
   playlist_ = pl;
-  if( pl.size() == 0 ) index_ = 0;
+  if( pl.empty() ) index_ = 0;
   else if( index_ >= pl.size() ) index_ = pl.size() - 1;
   }
 
